@@ -391,6 +391,29 @@ pub mod macros {
             remove(vec, &$element)
         };};
     }
+    /// vec_element_position_all!() used to find element position and collect into Vec<usize>
+    /// ```rust
+    ///let v1 = vec_element_position_all!(vec![1, 2, 5, 3, 6, 2, 2], 2);
+    ///assert_eq!(v1, vec![1, 5, 6]);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_position_all {
+        ($vec:expr,$element:expr) => {{
+            let mut vec = $vec.clone();
+            fn position<T: Copy + PartialOrd<T>>(vec: Vec<T>, target: &T) -> Vec<usize> {
+                let mut v1 = vec.clone();
+                let mut re = vec![];
+                for i in 0..v1.len() {
+                    if v1[i] == *target {
+                        re.push(i);
+                    }
+                }
+                re
+            }
+            position(vec, &$element)
+        };};
+    }
+
     /// slice_vec!() used to
     /// slice vec by range
     /// type can be Vec\<i32\> Vec\<i64\> Vec\<i128\> Vec\<f32\> Vec\<f64\>,Vec\<&str\>
@@ -488,9 +511,9 @@ pub mod macros {
             use std::path::Path;
             pub fn rm(path: &Path) {
                 if path.is_dir() {
-                    fs::remove_dir_all(path);
+                    fs::remove_dir_all(path).unwrap();
                 } else if path.is_file() {
-                    fs::remove_file(path);
+                    fs::remove_file(path).unwrap();
                 }
             }
             let path = Path::new($path);
@@ -498,29 +521,6 @@ pub mod macros {
         };};
     }
 
-    /// vec_element_position_all!() used to find element position and collect into Vec<usize>
-    /// ```rust
-    ///let v1 = vec_element_position_all!(vec![1, 2, 5, 3, 6, 2, 2], 2);
-    ///assert_eq!(v1, vec![1, 5, 6]);
-    /// ```
-    #[macro_export]
-    macro_rules! vec_element_position_all {
-        ($vec:expr,$element:expr) => {{
-            let mut vec = $vec.clone();
-            fn position<T: Copy + PartialOrd<T>>(vec: Vec<T>, target: &T) -> Vec<usize> {
-                let mut v1 = vec.clone();
-                let mut re = vec![];
-                for i in 0..v1.len() {
-                    if v1[i] == *target {
-                        re.push(i);
-                    }
-                }
-                re
-            }
-            position(vec, &$element)
-        };};
-    }
-
     pub fn run() {}
 }
 
